@@ -24,9 +24,9 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  ********************************************************************PGR-GNU*/
 
 #include <time.h>
-#include "./postgres_connection.h"
+#include "c_common/postgres_connection.h"
 
-#include "./time_msg.h"
+#include "c_common/time_msg.h"
 
 
 void time_msg(char *msg, clock_t start_t, clock_t end_t) {
