@@ -1,5 +1,5 @@
 \echo --q1
 SET client_min_messages TO WARNING;
 SELECT pgr_labelGraph('edge_table', 'id', 'source', 'target', 'subgraph');
-SELECT subgraph, count(*) FROM edge_table group by subgraph;
+SELECT DISTINCT subgraph FROM edge_table ORDER BY subgraph;
 \echo --q2
