@@ -38,16 +38,9 @@ if ! test -d code_linter; then
     cd ../..
 fi
 
-DIRECTORY=$1
+DIRECTORY="$1"
+
 if test -z "$DIRECTORY"; then
-    echo --------------------
-    echo ------   *.h  ------
-    echo --------------------
-    python code_linter/styleguide/cpplint/cpplint.py src/*/src/*.h
-    echo --------------------
-    echo ------ *.hpp  ------
-    echo --------------------
-    python code_linter/styleguide/cpplint/cpplint.py --extensions=hpp --headers=hpp --filter=-runtime/references src/*/src/*.hpp
     echo --------------------
     echo ------   *.c  ------
     echo --------------------
@@ -56,23 +49,54 @@ if test -z "$DIRECTORY"; then
     echo ------ *.cpp  ------
     echo --------------------
     python code_linter/styleguide/cpplint/cpplint.py --filter=-runtime/references src/*/src/*.cpp
+    echo --------------------
+    echo ------ HEADERS  ------
+    echo --------------------
+    python code_linter/styleguide/cpplint/cpplint.py --extensions=hpp,h --headers=hpp,h --filter=-runtime/references \
+        src/*/src/*.h \
+        src/*/src/*.hpp \
+        include/*/*.h* \
+        include/*/*/*.h*
+
 else
+    if [ "$DIRECTORY" = "h" ]; then
     echo --------------------
-    echo ------   *.c  ------
+    echo ------ OUT OF PLACE HEADERS  ------
     echo --------------------
-    python code_linter/styleguide/cpplint/cpplint.py --extensions=c --filter=-readability/casting src/$DIRECTORY/src/*.c
+    python code_linter/styleguide/cpplint/cpplint.py --extensions=hpp,h --headers=hpp,h --filter=-runtime/references \
+        src/*/src/*.h* 
+
     echo --------------------
-    echo ------ *.cpp  ------
+    echo ------ IN PLACE HEADERS  ------
     echo --------------------
-    python code_linter/styleguide/cpplint/cpplint.py --filter=-runtime/references src/$DIRECTORY/src/*.cpp
-    echo --------------------
-    echo ------   *.h  ------
-    echo --------------------
-    python code_linter/styleguide/cpplint/cpplint.py src/$DIRECTORY/src/*.h
-    echo --------------------
-    echo ------ *.hpp  ------
-    echo --------------------
-    python code_linter/styleguide/cpplint/cpplint.py --extensions=hpp --headers=hpp --filter=-runtime/references src/$DIRECTORY/src/*.hpp
+    python code_linter/styleguide/cpplint/cpplint.py --extensions=hpp,h --headers=hpp,h --filter=-runtime/references \
+        include/*/*.h* \
+        include/*/*/*.h*
+
+    else
+        echo --------------------
+        echo ------   *.c  ------
+        echo --------------------
+        python code_linter/styleguide/cpplint/cpplint.py --extensions=c --filter=-readability/casting src/$DIRECTORY/src/*.c
+        echo --------------------
+        echo ------ *.cpp  ------
+        echo --------------------
+        python code_linter/styleguide/cpplint/cpplint.py --filter=-runtime/references src/$DIRECTORY/src/*.cpp
+        echo --------------------
+        echo ------   C HEADER  ------
+        echo --------------------
+        python code_linter/styleguide/cpplint/cpplint.py \
+            include/drivers/$DIRECTORY/*.h \
+            include/c_types/$DIRECTORY/*.h
+
+        echo --------------------
+        echo ------ C++ HEADER  ------
+        echo --------------------
+        python code_linter/styleguide/cpplint/cpplint.py  --extensions=hpp,h --headers=hpp --filter=-runtime/references include/$DIRECTORY/*.h*
+        echo --------------------
+        echo ------ this shouild fail  ------
+        echo --------------------
+        python code_linter/styleguide/cpplint/cpplint.py src/$DIRECTORY/src/*.h*
+    fi
 fi
 
-
