@@ -5,16 +5,19 @@ SET client_min_messages = WARNING;
 
 ------------------------------------------------------------------------------------------------------
 ------------------------------------------------------------------------------------------------------
---              SAMPLE DATA                
+--              SAMPLE DATA
 ------------------------------------------------------------------------------------------------------
 ------------------------------------------------------------------------------------------------------
 
-    DROP TABLE IF EXISTS edge_table;
-    DROP TABLE IF EXISTS edge_table_vertices_pgr;
-    DROP table if exists pointsOfInterest;
-    DROP TABLE IF EXISTS restrictions;
-    DROP TABLE IF EXISTS vertex_table;
-    DROP TABLE IF EXISTS categories;
+DROP TABLE IF EXISTS edge_table;
+DROP TABLE IF EXISTS edge_table_vertices_pgr;
+DROP table if exists pointsOfInterest;
+DROP TABLE IF EXISTS restrictions;
+DROP TABLE IF EXISTS retrict;
+DROP TABLE IF EXISTS vertex_table;
+DROP TABLE IF EXISTS categories;
+DROP TABLE IF EXISTS vehicles;
+DROP TABLE IF EXISTS orders;
 
 --EDGE TABLE CREATE
 CREATE TABLE edge_table (
@@ -24,6 +27,8 @@ CREATE TABLE edge_table (
     target BIGINT,
     cost FLOAT,
     reverse_cost FLOAT,
+    capacity BIGINT,
+    reverse_capacity BIGINT,
     category_id INTEGER,
     reverse_category_id INTEGER,
     x1 FLOAT,
@@ -36,26 +41,27 @@ CREATE TABLE edge_table (
 INSERT INTO edge_table (
     category_id, reverse_category_id,
     cost, reverse_cost,
+    capacity, reverse_capacity,
     x1, y1,
-    x2, y2) VALUES 
-(3, 1,    1,  1,  2,   0,    2, 1),
-(3, 2,   -1,  1,  2,   1,    3, 1),
-(2, 1,   -1,  1,  3,   1,    4, 1),
-(2, 4,    1,  1,  2,   1,    2, 2),
-(1, 4,    1, -1,  3,   1,    3, 2),
-(4, 2,    1,  1,  0,   2,    1, 2),
-(4, 1,    1,  1,  1,   2,    2, 2),
-(2, 1,    1,  1,  2,   2,    3, 2),
-(1, 3,    1,  1,  3,   2,    4, 2),
-(1, 4,    1,  1,  2,   2,    2, 3),
-(1, 2,    1, -1,  3,   2,    3, 3),
-(2, 3,    1, -1,  2,   3,    3, 3),
-(2, 4,    1, -1,  3,   3,    4, 3),
-(3, 1,    1,  1,  2,   3,    2, 4),
-(3, 4,    1,  1,  4,   2,    4, 3),
-(3, 3,    1,  1,  4,   1,    4, 2),
-(1, 2,    1,  1,  0.5, 3.5,  1.999999999999,3.5),
-(4, 1,    1,  1,  3.5, 2.3,  3.5,4);
+    x2, y2) VALUES
+(3, 1,    1,  1,  80, 130,   2,   0,    2, 1),
+(3, 2,   -1,  1,  -1, 100,   2,   1,    3, 1),
+(2, 1,   -1,  1,  -1, 130,   3,   1,    4, 1),
+(2, 4,    1,  1, 100,  50,   2,   1,    2, 2),
+(1, 4,    1, -1, 130,  -1,   3,   1,    3, 2),
+(4, 2,    1,  1,  50, 100,   0,   2,    1, 2),
+(4, 1,    1,  1,  50, 130,   1,   2,    2, 2),
+(2, 1,    1,  1, 100, 130,   2,   2,    3, 2),
+(1, 3,    1,  1, 130,  80,   3,   2,    4, 2),
+(1, 4,    1,  1, 130,  50,   2,   2,    2, 3),
+(1, 2,    1, -1, 130,  -1,   3,   2,    3, 3),
+(2, 3,    1, -1, 100,  -1,   2,   3,    3, 3),
+(2, 4,    1, -1, 100,  -1,   3,   3,    4, 3),
+(3, 1,    1,  1,  80, 130,   2,   3,    2, 4),
+(3, 4,    1,  1,  80,  50,   4,   2,    4, 3),
+(3, 3,    1,  1,  80,  80,   4,   1,    4, 2),
+(1, 2,    1,  1, 130, 100,   0.5, 3.5,  1.999999999999,3.5),
+(4, 1,    1,  1,  50, 130,   3.5, 2.3,  3.5,4);
 
 UPDATE edge_table SET the_geom = st_makeline(st_point(x1,y1),st_point(x2,y2)),
 dir = CASE WHEN (cost>0 AND reverse_cost>0) THEN 'B'   -- both ways
@@ -108,7 +114,7 @@ INSERT INTO restrictions (rid, to_cost, target_id, from_edge, via_path) VALUES
 (3, 100,  9, 16, NULL);
 
 --RESTRICTIONS END
-
+/*
 CREATE TABLE categories (
     category_id INTEGER,
     category text,
@@ -120,9 +126,10 @@ INSERT INTO categories VALUES
 (2, 'Category 2', 100),
 (3, 'Category 3',  80),
 (4, 'Category 4',  50);
-
+*/
 --CATEGORIES END
 
+-- TODO check if this table is still used
 CREATE TABLE vertex_table (
     id SERIAL,
     x FLOAT,
@@ -134,3 +141,62 @@ INSERT INTO vertex_table VALUES
 
 --VERTEX TABLE END
 
+
+--VEHICLES TABLE START
+
+CREATE TABLE vehicles (
+      id BIGSERIAL PRIMARY KEY,
+      start_node_id BIGINT,
+      start_x FLOAT,
+      start_y FLOAT,
+      start_open FLOAT,
+      start_close FLOAT,
+      number integer,
+      capacity FLOAT
+);
+
+INSERT INTO vehicles
+(start_node_id, start_x,  start_y,  start_open,  start_close,  number,  capacity) VALUES
+(            6,       3,        2,           0,           50,       2,        50);
+
+--VEHICLES TABLE END
+
+
+
+--ORDERS TABLE START
+CREATE TABLE orders (
+    id BIGSERIAL PRIMARY KEY,
+    demand FLOAT,
+    -- the pickups
+    p_node_id BIGINT,
+    p_x FLOAT,
+    p_y FLOAT,
+    p_open FLOAT,
+    p_close FLOAT,
+    p_service FLOAT,
+    -- the deliveries
+    d_node_id BIGINT,
+    d_x FLOAT,
+    d_y FLOAT,
+    d_open FLOAT,
+    d_close FLOAT,
+    d_service FLOAT
+);
+
+
+INSERT INTO orders
+(demand,
+    p_node_id,  p_x, p_y,  p_open,  p_close,  p_service,
+    d_node_id,  d_x, d_y,  d_open,  d_close,  d_service) VALUES
+(10,
+            3,    3,   1,      2,         10,          3,
+            8,    1,   2,      6,         15,          3),
+(20,
+            9,    4,   2,      4,         15,          2,
+            4,    4,   1,      6,         20,          3),
+(30,
+            5,    2,   2,      2,         10,          3,
+           11,    3,   3,      3,         20,          3);
+
+
+--ORDERS TABLE END
